@@ -32,6 +32,14 @@ pub type ForAllHandler<ItemType, Properties> = fn(&ObjectPosition, &mut [ItemTyp
 /// is currently iterating over.
 pub type UpdateHandler<ItemType, Properties> = fn(&mut SwarmControl<ItemType, Properties>);
 
+pub type FactoryHandler<ItemType, Properties> = fn(&mut ItemType, &mut Properties);
+
+
+pub struct Factory<ItemType, Properties> {
+    pub type_def: usize,
+    pub methode: FactoryHandler<ItemType, Properties>,
+}
+
 // spawns and tags
 
 /// A spawn is a pointer that points to a data object in the swarm pool.
